#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 containers-unicode-symbols
version:              0.3.1.3
visibility:           public
id:                   containers-unicode-symbols-0.3.1.3-FmGa1BBVcTy9PsJA59rYQP
key:                  containers-unicode-symbols-0.3.1.3-FmGa1BBVcTy9PsJA59rYQP
license:              BSD-3-Clause
copyright:            2009—2021 Roel van Dijk <roel@lambdeacube.nl>
maintainer:           Roel van Dijk <roel@lambdeacube.nl>
author:               Roel van Dijk <roel@lambdeacube.nl>
stability:            provisional
homepage:             http://haskell.org/haskellwiki/Unicode-symbols
synopsis:             Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions and
    operators in the containers package.

    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.

abi:                  508c9d778b749e5f169a56a47f6cdba1
exposed:              True
exposed-modules:
    Data.IntMap.Lazy.Unicode Data.IntMap.Strict.Unicode
    Data.IntMap.Unicode Data.IntSet.Unicode Data.Map.Lazy.Unicode
    Data.Map.Strict.Unicode Data.Map.Unicode Data.Sequence.Unicode
    Data.Set.Unicode

import-dirs:
    /usr/lib/ghc-8.10.5/site-local/containers-unicode-symbols-0.3.1.3

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/containers-unicode-symbols-0.3.1.3

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/containers-unicode-symbols-0.3.1.3

hs-libraries:         HScontainers-unicode-symbols-0.3.1.3-FmGa1BBVcTy9PsJA59rYQP
depends:
    base-4.14.2.0 base-unicode-symbols-0.2.4.2-91RZnOG3rhvDK4lQIU0nQT
    containers-0.6.4.1

haddock-interfaces:
    /usr/share/doc/haskell-containers-unicode-symbols/html/containers-unicode-symbols.haddock

haddock-html:         /usr/share/doc/haskell-containers-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

